



if not exist %PREFIX%/Library/lib/libXaw3d.dll.a exit /b 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%/Library/lib/libXaw3d.a exit /b 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%/Library/lib/libXaw3d.la exit /b 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%/Library/bin/msys-Xaw3d-*.dll exit /b 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
